@@ -33,7 +33,9 @@ class ShotCollection(EntityView):
 
     ICON = ('icons.flow', 'shot')
 
-    add_shot = flow.Child(SimpleCreateAction)
+    add_shot_action = flow.Child(SimpleCreateAction).ui(
+        label='Add shot'
+    )
     
     @classmethod
     def mapped_type(cls):
